@@ -990,7 +990,6 @@ class Unet(nn.Module):
 
         # whether to use linear attention or not for layers where normal attention is computationally prohibitive
 
-        full_attn_substitute = partial(LinearAttentionTransformerBlock, heads = attn_heads, dim_head = attn_dim_head, dropout = dropout) if use_linear_attn else nn.Identity
 
         # layers
 
@@ -1005,7 +1004,7 @@ class Unet(nn.Module):
             is_last = ind >= (num_resolutions - 1)
             layer_cond_dim = cond_dim if layer_cross_attn else None
 
-            transformer_block_klass = TransformerBlock if layer_attn else LinearAttentionTransformerBlock
+            transformer_block_klass = TransformerBlock if layer_attn else (LinearAttentionTransformerBlock if use_linear_attn else nn.Identity)
 
             self.downs.append(nn.ModuleList([
                 ResnetBlock(dim_in, dim_out, cond_dim = layer_cond_dim, time_cond_dim = time_cond_dim, groups = groups),
@@ -1022,7 +1021,7 @@ class Unet(nn.Module):
 
         for ind, ((dim_in, dim_out), layer_num_resnet_blocks, groups, layer_attn, layer_cross_attn) in enumerate(zip(reversed(in_out[1:]), *reversed_layer_params)):
             layer_cond_dim = cond_dim if layer_cross_attn else None
-            transformer_block_klass = TransformerBlock if layer_attn else LinearAttentionTransformerBlock
+            transformer_block_klass = TransformerBlock if layer_attn else (LinearAttentionTransformerBlock if use_linear_attn else nn.Identity)
 
             self.ups.append(nn.ModuleList([
                 ResnetBlock(dim_out * 2, dim_in, cond_dim = layer_cond_dim, time_cond_dim = time_cond_dim, groups = groups),
